@@ -38,15 +38,20 @@ QList<QAction*> ExtractFileItemAction::actions(const KFileItemListProperties& fi
     // Filter URLs by supported mimetypes.
     const auto urlList = fileItemInfos.urlList();
     for (const QUrl &url : urlList) {
-        const QMimeType mimeType = determineMimeType(url.path());
+        if (!url.isLocalFile()) {
+            continue;
+        }
+        const QMimeType mimeType = determineMimeType(url.toLocalFile());
         if (m_pluginManager->preferredPluginsFor(mimeType).isEmpty()) {
             continue;
         }
         supportedUrls << url;
         // Check whether we can write in the parent directory of the file.
-        const QString directory = url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
-        if (!QFileInfo(directory).isWritable()) {
-            readOnlyParentDir = true;
+        if (!readOnlyParentDir) {
+            const QString directory = url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
+            if (!QFileInfo(directory).isWritable()) {
+                readOnlyParentDir = true;
+            }
         }
     }
 
