@@ -1,27 +1,8 @@
 /*
- * Copyright (c) 2016 Vladyslav Batyrenko <mvlabat@gmail.com>
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ( INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION ) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * ( INCLUDING NEGLIGENCE OR OTHERWISE ) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+    SPDX-FileCopyrightText: 2016 Vladyslav Batyrenko <mvlabat@gmail.com>
+
+    SPDX-License-Identifier: BSD-2-Clause
+*/
 
 #include "abstractaddtest.h"
 #include "archiveentry.h"
@@ -267,12 +248,12 @@ void CopyTest::testCopying()
     QStringList oldPaths = getEntryPaths(archive);
 
     // Check that the entries to be copied are in the archive.
-    for (const auto entry : qAsConst(targetEntries)) {
+    for (const auto entry : std::as_const(targetEntries)) {
         QVERIFY(oldPaths.contains(entry->fullPath()));
     }
 
     // Check that the expected paths (after the CopyJob) are not in the archive.
-    for (const auto &expectedPath : qAsConst(expectedNewPaths)) {
+    for (const auto &expectedPath : std::as_const(expectedNewPaths)) {
         QVERIFY(!oldPaths.contains(expectedPath));
     }
 
@@ -285,12 +266,12 @@ void CopyTest::testCopying()
     QStringList newPaths = getEntryPaths(archive);
 
     // Check that the expected paths are now in the archive.
-    for (const auto &path : qAsConst(expectedNewPaths)) {
+    for (const auto &path : std::as_const(expectedNewPaths)) {
         QVERIFY(newPaths.contains(path));
     }
 
     // Check also that the target paths are still in the archive.
-    for (const auto entry : qAsConst(targetEntries)) {
+    for (const auto entry : std::as_const(targetEntries)) {
         QVERIFY(newPaths.contains(entry->fullPath()));
     }
 
