@@ -232,6 +232,8 @@ LoadJob::LoadJob(Archive *archive, ReadOnlyArchiveInterface *interface)
     , m_dirCount(0)
     , m_filesCount(0)
 {
+    // Don't show "finished" notification when finished
+    setProperty("transientProgressReporting", true);
     qCDebug(ARK) << "Created job instance";
     connect(this, &LoadJob::newEntry, this, &LoadJob::onNewEntry);
 }
@@ -448,6 +450,7 @@ CreateJob::CreateJob(Archive *archive, const QVector<Archive::Entry*> &entries,
     , m_options(options)
 {
     qCDebug(ARK) << "Created job instance";
+    setTotalAmount(Files, 1);
 }
 
 CreateJob::~CreateJob()
@@ -563,6 +566,11 @@ TempExtractJob::TempExtractJob(Archive::Entry *entry, bool passwordProtectedHint
     m_tmpExtractDir = new QTemporaryDir();
 }
 
+Archive::Entry *TempExtractJob::entry() const
+{
+    return m_entry;
+}
+
 QString TempExtractJob::validatedFilePath() const
 {
     QString path = extractionDir() + QLatin1Char('/') + m_entry->fullPath();
